==> scipoptsuite-9.2.2.tgz: scipoptsuite-9.2.2/gcg/src/gcg/struct_consclassifier.h <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/*                                                                           */
/*                  This file is part of the program                         */
/*          GCG --- Generic Column Generation                                */
/*                  a Dantzig-Wolfe decomposition based extension            */
/*                  of the branch-cut-and-price framework                    */
/*         SCIP --- Solving Constraint Integer Programs                      */
/*                                                                           */
/* Copyright (C) 2010-2025 Operations Research, RWTH Aachen University       */
/*                         Zuse Institute Berlin (ZIB)                       */
/*                                                                           */
/* This program is free software; you can redistribute it and/or             */
/* modify it under the terms of the GNU Lesser General Public License        */
/* as published by the Free Software Foundation; either version 3            */
/* of the License, or (at your option) any later version.                    */
/*                                                                           */
/* This program is distributed in the hope that it will be useful,           */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of            */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             */
/* GNU Lesser General Public License for more details.                       */
/*                                                                           */
/* You should have received a copy of the GNU Lesser General Public License  */
/* along with this program; if not, write to the Free Software               */
/* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.*/
/*                                                                           */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

/**@file   struct_consclassifier.h
 * @ingroup DATASTRUCTURES
 * @brief  data structures for constraint classifiers
 * @author William Ma
 */

/*---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8----+----9----+----0----+----1----+----2*/

#ifndef GCG_STRUCT_CONSCLASSIFIER_H__
#define GCG_STRUCT_CONSCLASSIFIER_H__

#include "type_consclassifier.h"


/** detector data structure */
struct GCG_ConsClassifier {
   const char*           name;               /**< name of the detector */
   const char*           description;        /**< description of the detector */
   int                   priority;           /**< classifier priority */

   SCIP_Bool             enabled;        /* is enabled by default */

   GCG_CLASSIFIERDATA*   clsdata;            /**< custom data structure of the classifiers */

   GCG_DECL_FREECONSCLASSIFIER((*freeClassifier));                  /**< destructor of detector */
   GCG_DECL_CONSCLASSIFY((*classify));            /**< structure detection method of detector */
};


#endif //GCG_STRUCT_CONSCLASSIFIER_H__

==> scipoptsuite-10.0.1.tgz: scipoptsuite-10.0.1/gcg/src/gcg/struct_consclassifier.h <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/*                                                                           */
/*                  This file is part of the program and library             */
/*          GCG --- Generic Column Generation                                */
/*                  a Dantzig-Wolfe decomposition based extension            */
/*                  of the branch-cut-and-price framework                    */
/*         SCIP --- Solving Constraint Integer Programs                      */
/*                                                                           */
/* Copyright (C) 2010-2026 Operations Research, RWTH Aachen University       */
/*                         Zuse Institute Berlin (ZIB)                       */
/*                                                                           */
/*  Licensed under the Apache License, Version 2.0 (the "License");          */
/*  you may not use this file except in compliance with the License.         */
/*  You may obtain a copy of the License at                                  */
/*                                                                           */
/*      http://www.apache.org/licenses/LICENSE-2.0                           */
/*                                                                           */
/*  Unless required by applicable law or agreed to in writing, software      */
/*  distributed under the License is distributed on an "AS IS" BASIS,        */
/*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. */
/*  See the License for the specific language governing permissions and      */
/*  limitations under the License.                                           */
/*                                                                           */
/*  You should have received a copy of the Apache-2.0 license                */
/*  along with GCG; see the file LICENSE. If not visit gcg.or.rwth-aachen.de.*/
/*                                                                           */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

/**@file   struct_consclassifier.h
 * @ingroup DATASTRUCTURES
 * @brief  data structures for constraint classifiers
 * @author William Ma
 */

/*---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8----+----9----+----0----+----1----+----2*/

#ifndef GCG_STRUCT_CONSCLASSIFIER_H__
#define GCG_STRUCT_CONSCLASSIFIER_H__

#include "gcg/type_consclassifier.h"


/** detector data structure */
struct GCG_ConsClassifier {
   const char*           name;               /**< name of the detector */
   const char*           description;        /**< description of the detector */
   int                   priority;           /**< classifier priority */

   SCIP_Bool             enabled;        /* is enabled by default */

   GCG_CLASSIFIERDATA*   clsdata;            /**< custom data structure of the classifiers */

   GCG_DECL_FREECONSCLASSIFIER((*freeClassifier));                  /**< destructor of detector */
   GCG_DECL_CONSCLASSIFY((*classify));            /**< structure detection method of detector */
};


#endif //GCG_STRUCT_CONSCLASSIFIER_H__
